@@ -1,5 +1,5 @@
 from base64 import b64encode
-from dataclasses import dataclass, fields
+from dataclasses import InitVar, dataclass, fields
 from io import BytesIO
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Type, TypeVar, Union
@@ -36,7 +36,8 @@ class Element:
             return f'{key}="{escape(str(value))}"'
 
         attrs = " ".join(_attr(k, v) for k, v in vars(self).items() if not k.startswith("_"))
-        return f"<{self.get_type()} {attrs} />"
+        attrs = f" {attrs}" if attrs else ""
+        return f"<{self.get_type()}{attrs}/>"
 
 
 @dataclass
@@ -74,15 +75,30 @@ class Sharp(Element):
 
 
 @dataclass
-class Link(Text):
+class Link(Element):
+    url: str
+    display: Optional[str] = None
+
+    @override
+    @classmethod
+    def from_raw(cls, raw: RawElement) -> "Link":
+        res = cls(raw.attrs["href"], raw.children[0].attrs["text"] if raw.children else None)
+        for k, v in raw.attrs.items():
+            if k != "href":
+                setattr(res, k, v)
+        return res
+
     @override
     def __str__(self):
-        return f'<a href="{escape(self.text)}"/>'
+        if not self.display:
+            return f'<a href="{escape(self.url)}"/>'
+        return f'<a href="{escape(self.url)}">{escape(self.display)}</a>'
 
 
 @dataclass
 class Resource(Element):
     src: str
+    extra: InitVar[Optional[Dict[str, Any]]] = None
     cache: Optional[bool] = None
     timeout: Optional[str] = None
 
@@ -93,11 +109,12 @@ class Resource(Element):
         path: Optional[Union[str, Path]] = None,
         raw: Optional[Union[bytes, BytesIO]] = None,
         mime: Optional[str] = None,
+        extra: Optional[Dict[str, Any]] = None,
         cache: Optional[bool] = None,
         timeout: Optional[str] = None,
     ):
-        data: Dict[str, Any]
-        if url:
+        data: Dict[str, Any] = {"extra": extra}
+        if url is not None:
             data = {"src": url}
         elif path:
             data = {"src": Path(path).as_uri()}
@@ -112,6 +129,11 @@ class Resource(Element):
             data["timeout"] = timeout
         return cls(**data)
 
+    def __post_init__(self, extra: Optional[Dict[str, Any]] = None):
+        if extra:
+            for k, v in extra.items():
+                setattr(self, k, True if v is ... else v)
+
 
 @dataclass
 class Image(Resource):
@@ -138,70 +160,81 @@ class File(Resource):
 
 
 @dataclass
-class Bold(Text):
+class Style(Text):
+    @override
+    @classmethod
+    def from_raw(cls, raw: RawElement):
+        res = cls(raw.children[0].attrs["text"])
+        for k, v in raw.attrs.items():
+            setattr(res, k, v)
+        return res
+
+
+@dataclass
+class Bold(Style):
     @override
     def __str__(self):
         return f"<b>{escape(self.text)}</b>"
 
 
 @dataclass
-class Italic(Text):
+class Italic(Style):
     @override
     def __str__(self):
         return f"<i>{escape(self.text)}</i>"
 
 
 @dataclass
-class Underline(Text):
+class Underline(Style):
     @override
     def __str__(self):
         return f"<u>{escape(self.text)}</u>"
 
 
 @dataclass
-class Strikethrough(Text):
+class Strikethrough(Style):
     @override
     def __str__(self):
         return f"<s>{escape(self.text)}</s>"
 
 
 @dataclass
-class Spoiler(Text):
+class Spoiler(Style):
     @override
     def __str__(self):
         return f"<spl>{escape(self.text)}</spl>"
 
 
 @dataclass
-class Code(Text):
+class Code(Style):
     @override
     def __str__(self):
         return f"<code>{escape(self.text)}</code>"
 
 
 @dataclass
-class Superscript(Text):
+class Superscript(Style):
     @override
     def __str__(self):
         return f"<sup>{escape(self.text)}</sup>"
 
 
 @dataclass
-class Subscript(Text):
+class Subscript(Style):
     @override
     def __str__(self):
         return f"<sub>{escape(self.text)}</sub>"
 
 
 @dataclass
-class Br(Text):
+class Br(Style):
     @override
     def __str__(self):
         return "<br/>"
 
 
 @dataclass
-class Paragraph(Text):
+class Paragraph(Style):
     @override
     def __str__(self):
         return f"<p>{escape(self.text)}</p>"
@@ -209,9 +242,23 @@ class Paragraph(Text):
 
 @dataclass
 class Message(Element):
-    id: Optional[str] = None
-    forward: Optional[bool] = None
-    content: Optional[List[Element]] = None
+    id: Optional[str]
+    forward: Optional[bool]
+    content: List[Element]
+
+    def __init__(
+        self,
+        id: Optional[str] = None,
+        forward: Optional[bool] = None,
+        content: Optional[List[Union[str, Element]]] = None,
+    ):
+        self.id = id
+        self.forward = forward
+        self.content = [Text(i) if isinstance(i, str) else i for i in content or []]
+
+    def __call__(self, *content: Union[str, Element]):
+        self.content.extend(Text(i) if isinstance(i, str) else i for i in content)
+        return self
 
     @override
     def __str__(self):
@@ -221,10 +268,11 @@ class Message(Element):
         if self.forward:
             attr.append("forward")
         _type = self.get_type()
+        attrs = (" " + " ".join(attr)) if attr else ""
         if not self.content:
-            return f'<{_type} {" ".join(attr)} />'
+            return f"<{_type}{attrs}/>"
         else:
-            return f'<{_type} {" ".join(attr)}>{"".join(str(e) for e in self.content)}</{_type}>'
+            return f'<{_type}{attrs}>{"".join(str(e) for e in self.content)}</{_type}>'
 
 
 @dataclass
@@ -239,6 +287,57 @@ class Author(Element):
     avatar: Optional[str] = None
 
 
+@dataclass
+class Custom(Element):
+    type: str
+    attrs: Dict[str, Any]
+    children: List[Element]
+
+    def __init__(
+        self,
+        type: str,
+        attrs: Optional[Dict[str, Any]] = None,
+        children: Optional[List[Union[str, Element]]] = None,
+    ):
+        self.type = type
+        self.attrs = attrs or {}
+        self.children = [Text(i) if isinstance(i, str) else i for i in children or []]
+
+    def __call__(self, *children: Union[str, Element]):
+        self.children.extend(Text(i) if isinstance(i, str) else i for i in children)
+        return self
+
+    @override
+    def get_type(self) -> str:
+        return self.type
+
+    @override
+    def __str__(self) -> str:
+        def _attr(key: str, value: Any):
+            if value is True:
+                return key
+            if value is False:
+                return f"no-{key}"
+            if isinstance(value, (int, float)):
+                return f"{key}={value}"
+            return f'{key}="{escape(str(value))}"'
+
+        attrs = " ".join(_attr(k, v) for k, v in self.attrs.items() if not k.startswith("_"))
+        attrs = f" {attrs}" if attrs else ""
+        if self.children:
+            return f"<{self.get_type()}{attrs}>{''.join(str(e) for e in self.children)}</{self.get_type()}>"
+        return f"<{self.get_type()}{attrs}/>"
+
+
+@dataclass
+class Raw(Element):
+    content: str
+
+    @override
+    def __str__(self):
+        return self.content
+
+
 ELEMENT_TYPE_MAP = {
     "text": Text,
     "at": At,
@@ -274,22 +373,47 @@ def transform(elements: List[RawElement]) -> List[Element]:
             seg_cls = ELEMENT_TYPE_MAP[elem.type]
             msg.append(seg_cls.from_raw(elem))
         elif elem.type in ("a", "link"):
-            msg.append(Link(elem.attrs["href"]))
+            msg.append(Link.from_raw(elem))
         elif elem.type in STYLE_TYPE_MAP:
             seg_cls = STYLE_TYPE_MAP[elem.type]
-            msg.append(seg_cls(elem.children[0].attrs["text"]))  # type: ignore
+            msg.append(seg_cls.from_raw(elem))
         elif elem.type in ("br", "newline"):
             msg.append(Br("\n"))
         elif elem.type == "message":
-            res = Message.from_raw(elem)
-            if elem.children:
-                res.content = transform(elem.children)
-            msg.append(res)
+            msg.append(Message.from_raw(elem)(*transform(elem.children)))
         elif elem.type == "quote":
-            res = Quote.from_raw(elem)
-            if elem.children:
-                res.content = transform(elem.children)
-            msg.append(res)
+            msg.append(Quote.from_raw(elem)(*transform(elem.children)))
         else:
-            msg.append(Text(str(elem)))
+            msg.append(Custom(elem.type, elem.attrs)(*transform(elem.children)))
     return msg
+
+
+class E:
+    text = Text
+    at = At
+    at_role = At.at_role
+    all = At.all
+    sharp = Sharp
+    link = Link
+    image = Image.of
+    audio = Audio.of
+    video = Video.of
+    file = File.of
+    bold = Bold
+    italic = Italic
+    underline = Underline
+    strikethrough = Strikethrough
+    spoiler = Spoiler
+    code = Code
+    sup = Superscript
+    sub = Subscript
+    br = Br
+    paragraph = Paragraph
+    message = Message
+    quote = Quote
+    author = Author
+    custom = Custom
+    raw = Raw
+
+    def __new__(cls, *args, **kwargs):
+        raise TypeError("E is not instantiable")
